@@ -2,6 +2,9 @@ import sys
 
 from .app import App
 
-if __name__ == "__main__":
+def main():
     app = App([])
-    sys.exit(app.exec_())
\ No newline at end of file
+    sys.exit(app.exec_())
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
